import request from '@/utils/request'


// 查询锁具机构-列表
export function listLockType(query) {
  return request({
    url: '/iscs/type/getIsLocksetTypePage',
    method: 'get',
    params: query
  })
}

// 获取锁具机构详细信息
export function getLockTypeInfo(repairId) {
  return request({
    url: '/iscs/type/selectIsLocksetTypeById?locksetTypeId=' + repairId,
    method: 'get'
  })
}

//新增锁具机构
export function addLockType(query) {
  return request({
    url: '/iscs/type/insertIsLocksetType',
    method: 'post',
    data: query
  })
}

// 修改锁具机构信息
export function updateLockType(data) {
  return request({
    url: '/iscs/type/updateIsLocksetType',
    method: 'post',
    data: data
  })
}

// 删除锁具机构信息
export function delLockType(repairId) {
  return request({
    url: '/iscs/type/deleteIsLocksetTypeByLocksetTypeIds?locksetTypeIds='+ repairId,
    method: 'post'

  })
}
